@@ -3,7 +3,7 @@ package Gruntmaster::App;
 use 5.014000;
 use warnings;
 
-our $VERSION = '5999.000_014';
+our $VERSION = '5999.000_015';
 
 use App::Cmd::Setup '-app';
 use Gruntmaster::Data;
@@ -21,7 +21,10 @@ sub global_opt_spec {
 
 sub table { shift->global_options->{table} }
 
-dbinit $ENV{GRUNTMASTER_DSN} // 'dbi:Pg:';
+sub run {
+	dbinit $ENV{GRUNTMASTER_DSN} // 'dbi:Pg:';
+	shift->SUPER::run(@_);
+}
 
 1;
 __END__
